@@ -5,14 +5,18 @@ import logging
 from contextlib import contextmanager
 
 import os
+import sys
 import types
 from six import string_types
 
 from dynaconf import default_settings
-from dynaconf.loaders import default_loader, module_loader
+from dynaconf.loaders import default_loader, module_loader, module_cleaner
 from dynaconf.loaders import yaml_loader
+from dynaconf.transformator import TransformatorList
 from dynaconf.utils.functional import LazyObject, empty
 from dynaconf.utils.parse_conf import converters, parse_conf_data
+from dynaconf.validator import ValidatorList
+from dynaconf.utils.boxing import DynaBox
 
 
 class LazySettings(LazyObject):
@@ -62,11 +66,13 @@ class LazySettings(LazyObject):
         handle initialization for the customization cases
         :param kwargs: values that overrides default_settings
         """
+        self._kwargs = kwargs
         for k, v in kwargs.items():
             setattr(default_settings, k.upper(), v)
         super(LazySettings, self).__init__()
 
     def __getattr__(self, name):
+        """Allow getting keys from self.store using dot notation"""
         if self._wrapped is empty:
             self._setup()
         if name in self._wrapped._deleted:  # noqa
@@ -80,12 +86,18 @@ class LazySettings(LazyObject):
         return getattr(self._wrapped, name)
 
     def __call__(self, *args, **kwargs):
+        """Allow direct call of settings('val')
+        in place of settings.get('val')
+        """
         return self.get(*args, **kwargs)
 
     def _setup(self):
+        """Initial setup, run once."""
         environment_variable = default_settings.ENVVAR_FOR_DYNACONF
         settings_module = os.environ.get(environment_variable)
-        self._wrapped = Settings(settings_module=settings_module)
+        self._wrapped = Settings(
+            settings_module=settings_module, **self._kwargs
+        )
 
     def configure(self, settings_module=None, **kwargs):
         """
@@ -94,10 +106,12 @@ class LazySettings(LazyObject):
         :param settings_module:
         :param kwargs:
         """
+        kwargs.update(self._kwargs)
         self._wrapped = Settings(settings_module=settings_module, **kwargs)
 
     @property
     def configured(self):
+        """If wrapped is configured"""
         return self._wrapped is not empty
 
 
@@ -123,26 +137,45 @@ class Settings(object):
     DYNACONF_ALWAYS_FRESH_VARS = None
 
     def __init__(self, settings_module=None, **kwargs):  # pragma: no cover
+        """Execute loaders and custom initialization"""
         if settings_module:
             self.set('SETTINGS_MODULE', settings_module)
-        self.execute_loaders()
         for key, value in kwargs.items():
             self.set(key, value)
+        # execute loaders only after setting defaults got from kwargs
+        self.execute_loaders()
 
     def __call__(self, *args, **kwargs):
+        """Allow direct call of settings('val')
+        in place of settings.get('val')
+        """
         return self.get(*args, **kwargs)
 
     def __setattr__(self, name, value):
+        """Allow settings.FOO = 'value' and deal with _deleted"""
         self._deleted.discard(name)
         super(Settings, self).__setattr__(name, value)
 
     def __delattr__(self, name):
+        """stores reference in _deleted for proper error management"""
         self._deleted.add(name)
         if hasattr(self, name):
             super(Settings, self).__delattr__(name)
 
+    def __getitem__(self, item):
+        """Allow getting variables as dict keys settings['KEY']"""
+        value = self.get(item)
+        if not value:
+            raise KeyError('{0} does not exists'.format(item))
+        return value
+
+    def __setitem__(self, key, value):
+        """Allow settings['KEY'] = 'value'"""
+        self.set(key, value)
+
     @property
     def store(self):
+        """Get or create internal storage"""
         if not self._store:
             self._store = {
                 key: value
@@ -153,9 +186,11 @@ class Settings(object):
         return self._store
 
     def keys(self):
+        """Redirects to store object"""
         return self.store.keys()
 
     def values(self):
+        """Redirects to store object"""
         return self.store.values()
 
     def get(self, key, default=None, cast=None, fresh=False):
@@ -180,7 +215,8 @@ class Settings(object):
         return data
 
     def exists(self, key, fresh=False):
-        """Check if key exists"""
+        """Check if key exists
+        NOTE: Must implement regex pattern here!!"""
         key = key.upper()
         if key in self._deleted:
             return False
@@ -218,39 +254,47 @@ class Settings(object):
         return key.upper() in self.env
 
     def as_bool(self, key):
+        """Partial method for get with cast"""
         return self.get(key, cast='@bool')
 
     def as_int(self, key):
+        """Partial method for get with cast"""
         return self.get(key, cast='@int')
 
     def as_float(self, key):
+        """Partial method for get with cast"""
         return self.get(key, cast='@float')
 
     def as_json(self, key):
+        """Partial method for get with cast"""
         return self.get(key, cast='@json')
 
     @property
     def logger(self):  # pragma: no cover
+        """Get or create inner logger"""
         if not self._logger:
             self._logger = logging.getLogger()
         return self._logger
 
     @property
     def loaded_namespaces(self):
+        """Get or create internal loaded namespaces list"""
         if not self._loaded_namespaces:
             self._loaded_namespaces = []
         return self._loaded_namespaces
 
     @loaded_namespaces.setter
     def loaded_namespaces(self, value):
+        """Setter for namespace list"""
         self._loaded_namespaces = value
 
     @property
     def loaded_by_loaders(self):
+        """Gets the internal mapping of LOADER -> values"""
         return self._loaded_by_loaders
 
     @contextmanager
-    def using_namespace(self, namespace, clean=True):
+    def using_namespace(self, namespace, clean=True, silent=False):
         """
         This context manager allows the contextual use of a different namespace
         Example:
@@ -267,10 +311,11 @@ class Settings(object):
 
         :param namespace: Upper case name of namespace without any _
         :param clean: If preloaded vars should be cleaned
+        :param silent: Silence errors
         :return: context
         """
         try:
-            self.namespace(namespace, clean=clean)
+            self.namespace(namespace, clean=clean, silent=silent)
             yield
         finally:
             if namespace != self.DYNACONF_NAMESPACE:
@@ -302,6 +347,7 @@ class Settings(object):
 
     @property
     def current_namespace(self):
+        """Return the current active namespace"""
         try:
             return self.loaded_namespaces[-1]
         except IndexError:
@@ -309,6 +355,7 @@ class Settings(object):
 
     @property
     def settings_module(self):
+        """Gets or initialize SETTINGS_MODULE variable"""
         if not self.SETTINGS_MODULE:
             environment_variable = getattr(
                 self,
@@ -324,7 +371,7 @@ class Settings(object):
 
         return self.SETTINGS_MODULE
 
-    def namespace(self, namespace=None, clean=True):
+    def namespace(self, namespace=None, clean=True, silent=True):
         """
         Used to interactively change the namespace
         $ export DYNACONF_MESSAGE='This is in DYNACONF namespace'
@@ -341,6 +388,7 @@ class Settings(object):
 
         :param namespace: Upper case namespace name without any _
         :param clean: Should clean preloaded vars?
+        :param silent: Silence errors
         :return: None
         """
         namespace = namespace or self.DYNACONF_NAMESPACE
@@ -356,29 +404,43 @@ class Settings(object):
             raise AttributeError('namespace should not contains _')
         if clean:
             self.clean(namespace=namespace)
-        self.execute_loaders(namespace=namespace)
+        self.execute_loaders(namespace=namespace, silent=silent)
 
     def clean(self, namespace=None, silent=None):
+        """Clean all loaded values to reload when switching namespaces"""
         silent = silent or self.DYNACONF_SILENT_ERRORS
         namespace = namespace or self.DYNACONF_NAMESPACE
         for loader in self.loaders:
             loader.clean(self, namespace, silent=silent)
+        yaml_loader.clean(self, namespace, silent=silent)
+        module_cleaner(self, namespace, silent=silent)
 
     def unset(self, key):
+        """Unset on all references"""
         key = key.strip().upper()
         delattr(self, key)
         self.store.pop(key, None)
 
     def unset_all(self, keys):  # pragma: no cover
+        """Unset based on a list of keys"""
         for key in keys:
             self.unset(key)
 
-    def set(self, key, value):
+    def set(self, key, value, loader_identifier=None):
+        """Set a value storing references for the loader"""
         value = parse_conf_data(value)
+        if isinstance(value, dict):
+            value = DynaBox(value, box_it_up=True)
+
         key = key.strip().upper()
         setattr(self, key, value)
         self.store[key] = value
 
+        if loader_identifier and loader_identifier in self.loaded_by_loaders:
+            self.loaded_by_loaders[loader_identifier][key] = value
+        elif loader_identifier:
+            self.loaded_by_loaders[loader_identifier] = {key: value}
+
     def update(self, data=None, loader_identifier=None, **kwargs):
         """
         Update values in the current settings object without saving in stores
@@ -405,6 +467,7 @@ class Settings(object):
 
     @property
     def loaders(self):  # pragma: no cover
+        """Return available loaders"""
         if not self._loaders:
             for loader_module_name in self.LOADERS_FOR_DYNACONF:
                 try:
@@ -415,21 +478,29 @@ class Settings(object):
         return self._loaders
 
     def reload(self, namespace=None, silent=None):  # pragma: no cover
+        """Execute all loaders"""
         self.execute_loaders(namespace, silent)
 
     def execute_loaders(self, namespace=None, silent=None, key=None):
+        """Execute all internal and registered loaders"""
+        silent = silent or self.DYNACONF_SILENT_ERRORS
         default_loader(self)
-        module_loader(self, namespace=namespace)
+        module_loader(self, namespace=namespace, silent=silent)
         if self.exists('YAML'):
             yaml_loader.load(
-                self, namespace=namespace, filename=self.get('YAML')
+                self, namespace=namespace,
+                filename=self.get('YAML'),
+                silent=silent
             )
-        silent = silent or self.DYNACONF_SILENT_ERRORS
         for loader in self.loaders:
             loader.load(self, namespace, silent=silent, key=key)
 
     @staticmethod
     def import_from_filename(filename, silent=False):  # pragma: no cover
+        """If settings_module is a path use this."""
+        if not filename.endswith('.py'):
+            filename = '{0}.py'.format(filename)
+
         if filename == default_settings.SETTINGS_MODULE_FOR_DYNACONF:
             silent = True
         mod = types.ModuleType('config')
@@ -441,13 +512,30 @@ class Settings(object):
                     mod.__dict__
                 )
         except IOError as e:
+            e.strerror = (
+                'Unable to load configuration file (%s %s)\n'
+            ) % (e.strerror, filename)
             if silent and e.errno in (errno.ENOENT, errno.EISDIR):
-                return False
-            e.strerror = 'Unable to load configuration file (%s)' % e.strerror
-            raise
+                return
+            sys.stderr.write(e.strerror)
         return mod
 
     def path_for(self, *args):
+        """Path containing project_root"""
         if args and args[0].startswith('/'):
             return os.path.join(*args)
         return os.path.join(self.PROJECT_ROOT, *args)
+
+    @property
+    def validators(self):
+        """Gets or creates validator wrapper"""
+        if not hasattr(self, '_validators'):
+            self._validators = ValidatorList(self)
+        return self._validators
+
+    @property
+    def transformators(self):
+        """Gets or creates transformator wrapper"""
+        if not hasattr(self, '_transformators'):
+            self._transformators = TransformatorList(self)
+        return self._transformators
