@@ -1,12 +1,13 @@
 # coding: utf-8
-import pytest
 import os
-from dynaconf import LazySettings
-# from dynaconf.loaders.redis_loader import write
+import pytest
+
+from dynaconf.base import LazySettings
 
 
 @pytest.fixture(scope='module')
 def settings():
+    """Settings fixture with some defaults"""
     mode = 'TRAVIS' if os.environ.get('TRAVIS') else 'TEST'
     os.environ['DYNA%s_HOSTNAME' % mode] = 'host.com'
     os.environ['DYNA%s_PORT' % mode] = '@int 5000'
@@ -21,12 +22,20 @@ def settings():
             'dynaconf.loaders.env_loader',
             'dynaconf.loaders.redis_loader'
         ],
-        DYNACONF_NAMESPACE="DYNA%s" % mode
+        DYNACONF_NAMESPACE="DYNA%s" % mode,
+        boxed_data={
+            'HOST': 'server.com',
+            'port': 8080,
+            'PARAMS': {
+                'username': 'admin',
+                'PASSWORD': 'secret',
+                'token': {
+                    'TYPE': 1,
+                    'value': 2
+                }
+            }
+        }
     )
+    sets.SIMPLE_BOOL = False
     sets.configure()
     return sets
-
-
-# def pytest_runtest_setup(item):
-#     # called for running each test in 'a' directory
-#     print("setting up", item)  # noqa
